@@ -1,5 +1,20 @@
-// base1464.c
-// fumiama 20211029
+/* base1464.c
+ * This file is part of the base16384 distribution (https://github.com/fumiama/base16384).
+ * Copyright (c) 2022 Fumiama Minamoto.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, version 3.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
+
 #include <stdio.h>
 #include <stdint.h>
 #include <stdlib.h>
@@ -46,7 +61,7 @@
 
 // #define DEBUG
 
-int encode(const char* data, int dlen, char* buf, int blen) {
+int base16384_encode(const char* data, int dlen, char* buf, int blen) {
 	int outlen = dlen / 7 * 8;
 	int offset = dlen % 7;
 	switch(offset) {	// 算上偏移标志字符占用的2字节
@@ -120,7 +135,7 @@ int encode(const char* data, int dlen, char* buf, int blen) {
 	return outlen;
 }
 
-int decode(const char* data, int dlen, char* buf, int blen) {
+int base16384_decode(const char* data, int dlen, char* buf, int blen) {
 	int outlen = dlen;
 	int offset = 0;
 	if(data[dlen-2] == '=') {
